@@ -5,6 +5,7 @@ import requests
 import base64
 import string
 import re
+import os
 from tusclient import client
 
 
@@ -34,7 +35,7 @@ class SlideScoreResult:
 
         self.image_id = int(dict['imageID'])
         self.image_name = dict['imageName']
-        self.case_name = dict['caseName']
+        self.case_name = dict['caseName'] if 'caseName' in dict else None
         self.user = dict['user']
         self.tma_row = int(dict['tmaRow']) if 'tmaRow' in dict else None
         self.tma_col = int(dict['tmaCol']) if 'tmaCol' in dict else None
@@ -328,7 +329,7 @@ class APIClient(object):
         if response.text != '"OK"':
             raise SlideScoreErrorException("Failed finishing upload: " + response.text);
          
-    def upload_file(self, source_filename, destination_path, destination_filename):
+    def upload_file(self, source_filename, destination_path, destination_filename=None):
         """
         Upload a file to the server.
         Parameters
@@ -338,9 +339,11 @@ class APIClient(object):
         destination_path: string
             path (without filename) on the server
         destination_filename: string 
-            filename to use on the server
+            filename to use on the server, None to use the source filename
         
         """
+        if destination_filename==None:
+            destination_filename = os.path.basename(source_filename)
         uploadToken = self.request_upload(destination_path, destination_filename, None)
         uploadClient = client.TusClient(self.end_point.replace('/Api/','/files/'))
         uploader = uploadClient.uploader(source_filename, chunk_size=10*1000*1000, metadata={'uploadtoken': uploadToken, 'apitoken': self.api_token})
@@ -354,7 +357,14 @@ class APIClient(object):
         response = self.perform_request("AddSlide", {"studyId": study_id, "path": destination_filename}, method="POST")
         if response.text != '"OK"':
             raise SlideScoreErrorException("Failed adding slide: " + response.text);
+
+    def reimport(self, study_name):
+        response = self.perform_request("Reimport", {"studyName": study_name}, method="POST")
+        if response.text[0] == '"':
+            raise SlideScoreErrorException("Failed reimporting: " + response.text);
+        rjson=response.json()
+        if not rjson["success"]:
+            raise SlideScoreErrorException("Failed reimporting: " + rjson["log"]);
+        return { "id": rjson['id'], "log": rjson["log"]}
         
-        
-    
-    
+  
